@@ -7,6 +7,7 @@ Created on 2015-8-8
 
 from PyFin.Analysis.DataProviders import DataProvider
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityDeltaValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityConstArrayValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
@@ -17,12 +18,14 @@ from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityVal
 from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSPercentileSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSResidueSecurityValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityCurrentValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis import TechnicalAnalysis
 from PyFin.Analysis.transformer import transform
 
 __all__ = ['DataProvider',
            'SecurityShiftedValueHolder',
+           'SecurityDeltaValueHolder',
            'SecurityIIFValueHolder',
            'SecurityConstArrayValueHolder',
            'CSRankedSecurityValueHolder',
@@ -33,6 +36,7 @@ __all__ = ['DataProvider',
            'CSZScoreSecurityValueHolder',
            'CSPercentileSecurityValueHolder',
            'CSResidueSecurityValueHolder',
+           'SecurityCurrentValueHolder',
            'SecurityLatestValueHolder',
            'TechnicalAnalysis',
            'transform']
