@@ -9,8 +9,11 @@ Created on 2015-9-23
 import functools
 
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingDecay
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingArgMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingArgMin
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRank
 from PyFin.Analysis.TechnicalAnalysis import SecurityMaximumValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMinimumValueHolder
@@ -39,7 +42,12 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAcoshValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityNormInvValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityCeilValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityFloorValueHolder
+from PyFin.Analysis.TechnicalAnalysis import SecurityRoundValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityDeltaValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityCurrentValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 
@@ -115,14 +123,26 @@ def MA(window, x='x'):
     return SecurityMovingAverage(window, x)
 
 
+def MADecay(window, x='x'):
+    return SecurityMovingDecay(window, x)
+
+
 def MMAX(window, x='x'):
     return SecurityMovingMax(window, x)
 
 
+def MARGMAX(window, x='x'):
+    return SecurityMovingArgMax(window, x)
+
+
 def MMIN(window, x='x'):
     return SecurityMovingMin(window, x)
 
 
+def MARGMIN(window, x='x'):
+    return SecurityMovingArgMin(window, x)
+
+
 def MRANK(window, x='x'):
     return SecurityMovingRank(window, x)
 
@@ -167,6 +187,10 @@ def MAPOSITIVE(window, x='x'):
     return SecurityMovingPositiveAverage(window, x)
 
 
+def CURRENT(x='x'):
+    return SecurityCurrentValueHolder(x)
+
+
 def LAST(x='x'):
     return SecurityLatestValueHolder(x)
 
@@ -223,14 +247,41 @@ def NORMINV(x):
     return SecurityNormInvValueHolder(x)
 
 
+def CEIL(x):
+    return SecurityCeilValueHolder(x)
+
+
+def FLOOR(x):
+    return SecurityFloorValueHolder(x)
+
+
+def ROUND(x):
+    return SecurityRoundValueHolder(x)
+
+
 def SHIFT(x, n):
     return SecurityShiftedValueHolder(x, n)
 
 
+def DELTA(x, n):
+    return SecurityDeltaValueHolder(x, n)
+
+
 def IIF(flag, left, right):
     return SecurityIIFValueHolder(flag, left, right)
 
 
+def INDUSTRY(name, level=1):
+    name = name.lower()
+    if name == 'sw':
+        if level in (1, 2, 3):
+            return LAST(name + str(level))
+        else:
+            raise ValueError('{0} is not recognized level for {1}'.format(level, name))
+    else:
+        raise ValueError('currently only `sw` industry is supported. {1} is not a recognized industry type')
+
+
 HIGH = functools.partial(LAST, 'highestPrice')
 LOW = functools.partial(LAST, 'lowestPrice')
 OPEN = functools.partial(LAST, 'openPrice')
