@@ -24,8 +24,11 @@ from PyFin.api.Analysis import EMA
 from PyFin.api.Analysis import MACD
 from PyFin.api.Analysis import RSI
 from PyFin.api.Analysis import MA
+from PyFin.api.Analysis import MADecay
 from PyFin.api.Analysis import MMAX
+from PyFin.api.Analysis import MARGMAX
 from PyFin.api.Analysis import MMIN
+from PyFin.api.Analysis import MARGMIN
 from PyFin.api.Analysis import MRANK
 from PyFin.api.Analysis import MAXIMUM
 from PyFin.api.Analysis import MINIMUM
@@ -37,6 +40,7 @@ from PyFin.api.Analysis import MVARIANCE
 from PyFin.api.Analysis import MSTD
 from PyFin.api.Analysis import MNPOSITIVE
 from PyFin.api.Analysis import MAPOSITIVE
+from PyFin.api.Analysis import CURRENT
 from PyFin.api.Analysis import LAST
 from PyFin.api.Analysis import HIGH
 from PyFin.api.Analysis import LOW
@@ -55,8 +59,12 @@ from PyFin.api.Analysis import ACOSH
 from PyFin.api.Analysis import ASIN
 from PyFin.api.Analysis import ASINH
 from PyFin.api.Analysis import NORMINV
+from PyFin.api.Analysis import CEIL
+from PyFin.api.Analysis import FLOOR
+from PyFin.api.Analysis import ROUND
 from PyFin.api.Analysis import SHIFT
 from PyFin.api.Analysis import IIF
+from PyFin.api.Analysis import INDUSTRY
 
 from PyFin.api.Analysis import CSRank
 from PyFin.api.Analysis import CSTopN
@@ -90,8 +98,11 @@ __all__ = ["datesList",
            "MACD",
            "RSI",
            "MA",
+           "MADecay",
            "MMAX",
+           "MARGMAX",
            "MMIN",
+           "MARGMIN",
            "MRANK",
            "MAXIMUM",
            "MINIMUM",
@@ -103,6 +114,7 @@ __all__ = ["datesList",
            "MSTD",
            "MNPOSITIVE",
            "MAPOSITIVE",
+           "CURRENT",
            "LAST",
            "HIGH",
            "LOW",
@@ -121,8 +133,12 @@ __all__ = ["datesList",
            "ASIN",
            "ASINH",
            "NORMINV",
+           "CEIL",
+           "FLOOR",
+           "ROUND",
            "SHIFT",
            "IIF",
+           "INDUSTRY",
            "CSRank",
            "CSTopN",
            "CSBottomN",
