@@ -15,10 +15,13 @@ import os
 from collections import deque
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingDecay
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingVariance
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingArgMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingArgMin
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRank
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
@@ -122,6 +125,38 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'expected:   {1:.12f}\n'
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
+    def testSecurityMovingDecay(self):
+        window = 10
+        ma1 = SecurityMovingDecay(window, ['close'])
+
+        def calculate_decay(con, k):
+            s = k - len(con) + 1
+            c = (k + s) * (k - s + 1) / 2.
+            sum_value = 0.
+            for w in range(s, k+1):
+                i = w - s
+                sum_value += w * con[i]
+            return sum_value / c
+
+        for i in range(len(self.aapl['close'])):
+            data = dict(aapl=dict(close=self.aapl['close'][i],
+                                  open=self.aapl['open'][i]),
+                        ibm=dict(close=self.ibm['close'][i],
+                                 open=self.ibm['open'][i]))
+            ma1.push(data)
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            value = ma1.value
+            for name in value.index():
+                expected = calculate_decay(self.dataSet[name]['close'][start:(i + 1)], window)
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected, calculated))
+
     def testSecurityMovingAverageWithErrorValues(self):
         window = 5
         to_average = SecurityLatestValueHolder('open') / SecurityLatestValueHolder('close')
@@ -250,13 +285,36 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'expected:   {1:.12f}\n'
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
+    def testSecurityMovingArgMax(self):
+        window = 10
+        ma1 = SecurityMovingArgMax(window, 'close')
+
+        for i in range(len(self.aapl['close'])):
+            data = dict(aapl=dict(close=self.aapl['close'][i],
+                                  open=self.aapl['open'][i]),
+                        ibm=dict(close=self.ibm['close'][i],
+                                 open=self.ibm['open'][i]))
+            ma1.push(data)
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            value = ma1.value
+            for name in value.index():
+                expected = i - start - np.argmax(self.dataSet[name]['close'][start:(i + 1)])
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected, calculated))
+
     def testSecurityMovingMaxDeepcopy(self):
         self.template_test_deepcopy(SecurityMovingMax, window=10, x=['x'])
 
     def testSecurityMovingMaxPickle(self):
         self.template_test_pickle(SecurityMovingMax, window=10, x=['x'])
 
-    def testSecurityMovingMinimum(self):
+    def testSecurityMovingMin(self):
         window = 10
         ma1 = SecurityMovingMin(window, 'close')
 
@@ -279,6 +337,29 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'expected:   {1:.12f}\n'
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
+    def testSecurityMovingArgMin(self):
+        window = 10
+        ma1 = SecurityMovingArgMin(window, 'close')
+
+        for i in range(len(self.aapl['close'])):
+            data = dict(aapl=dict(close=self.aapl['close'][i],
+                                  open=self.aapl['open'][i]),
+                        ibm=dict(close=self.ibm['close'][i],
+                                 open=self.ibm['open'][i]))
+            ma1.push(data)
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            value = ma1.value
+            for name in value.index():
+                expected = i - start - np.argmin(self.dataSet[name]['close'][start:(i + 1)])
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected, calculated))
+
     def testSecurityMovingMinimumDeepcopy(self):
         self.template_test_deepcopy(SecurityMovingMin, window=10, x='x')
 
@@ -644,4 +725,4 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
 
             if i >= 1:
                 self.assertAlmostEqual(max(container), compounded1.value['aapl'], 12)
-                self.assertAlmostEqual(np.mean((container)), compounded2.value['aapl'], 12)
\ No newline at end of file
+                self.assertAlmostEqual(np.mean((container)), compounded2.value['aapl'], 12)
