@@ -14,16 +14,21 @@ import tempfile
 import math
 import numpy as np
 from collections import deque
+from PyFin.Math.Accumulators import Current
 from PyFin.Math.Accumulators import Latest
 from PyFin.Math.Accumulators import Shift
+from PyFin.Math.Accumulators import Delta
 from PyFin.Math.Accumulators import Exp
 from PyFin.Math.Accumulators import MovingMax
+from PyFin.Math.Accumulators import MovingArgMax
 from PyFin.Math.Accumulators import MovingMin
+from PyFin.Math.Accumulators import MovingArgMin
 from PyFin.Math.Accumulators import MovingRank
 from PyFin.Math.Accumulators import MovingQuantile
 from PyFin.Math.Accumulators import MovingAllTrue
 from PyFin.Math.Accumulators import MovingAnyTrue
 from PyFin.Math.Accumulators import MovingAverage
+from PyFin.Math.Accumulators import MovingDecay
 from PyFin.Math.Accumulators import MovingPositiveAverage
 from PyFin.Math.Accumulators import MovingNegativeAverage
 from PyFin.Math.Accumulators import MovingPositiveDifferenceAverage
@@ -47,13 +52,21 @@ class TestStatefulAccumulators(unittest.TestCase):
         np.random.seed(0)
         self.sample = np.random.randn(10000)
 
+    def testCurrentValueHolderWithOtherValueHolder(self):
+        test1 = Exp(Current('x'))
+        test1.push({'x': 2.0})
+        self.assertAlmostEqual(test1.value, math.exp(2.0))
+
+        test1.push({'x': np.nan})
+        self.assertTrue(math.isnan(test1.value))
+
     def testLatestValueHolderWithOtherValueHolder(self):
         test1 = Exp(Latest('x'))
         test1.push({'x': 2.0})
         self.assertAlmostEqual(test1.value, math.exp(2.0))
 
         test1.push({'x': np.nan})
-        self.assertTrue(math.isnan(test1.value))
+        self.assertAlmostEqual(test1.value, math.exp(2.0))
 
     def testLatestValueHolderDeepCopy(self):
 
@@ -111,6 +124,29 @@ class TestStatefulAccumulators(unittest.TestCase):
         test.push(dict(close=10.0))
         self.assertAlmostEqual(previous, test.result())
 
+    def testDeltaValueHolder(self):
+        ma = MovingAverage(10, 'close')
+
+        with self.assertRaises(ValueError):
+            _ = Delta(ma, N=0)
+
+        test = Delta(ma, N=2)
+
+        test.push(dict(close=2.0))
+        ma.push(dict(close=2.0))
+        p_previous = ma.result()
+        test.push(dict(close=5.0))
+        ma.push(dict(close=5.0))
+        previous = ma.result()
+        test.push(dict(close=7.0))
+        ma.push(dict(close=7.0))
+
+        self.assertAlmostEqual(ma.result() - p_previous, test.result())
+
+        ma.push(dict(close=10.0))
+        test.push(dict(close=10.0))
+        self.assertAlmostEqual(ma.result() - previous, test.result())
+
     def testShiftValueHolderDeepcopy(self):
         ma = Latest('close')
         test = Shift(ma, N=2)
@@ -162,6 +198,37 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                                  "Average calculated: {2:f}".format(i, expected,
                                                                                                     calculated))
 
+    def testMovingDecay(self):
+        window = 80
+        total = 2500
+
+        mv = MovingDecay(window, 'z')
+
+        def calculate_decay(con, k):
+            s = k - len(con) + 1
+            c = (k + s) * (k - s + 1) / 2.
+            sum_value = 0.
+            for w in range(s, k + 1):
+                i = w - s
+                sum_value += w * con[i]
+            return sum_value / c
+
+        con = []
+        for i in range(total):
+            value = float(i)
+            con.append(value)
+            mv.push(dict(z=value))
+            if i >= window:
+                con = con[1:]
+
+            if i >= 1:
+                expected = calculate_decay(con, window)
+                calculated = mv.result()
+                self.assertAlmostEqual(calculated, expected, 15, "at index {0:d}\n"
+                                                                 "Average expected:   {1:f}\n"
+                                                                 "Average calculated: {2:f}".format(i, expected,
+                                                                                                    calculated))
+
     def testMovingAverageDeepcopy(self):
         window = 20
         mv = MovingAverage(window, 'x')
@@ -546,6 +613,42 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                              "Max expected:   {1:f}\n"
                                                              "Max calculated: {2:f}".format(i, expected, calculated))
 
+    def testMovingArgMax(self):
+        window = 120
+
+        mv = MovingArgMax(window, 'z')
+        total = np.random.randn(2500)
+        con = deque(maxlen=window)
+        for i, value in enumerate(total):
+            value = float(value)
+            con.append(value)
+            mv.push(dict(z=value))
+            runningMax = max(con)
+
+            expected = len(con) - np.where(np.array(con) == runningMax)[0][0] - 1.
+            calculated = mv.result()
+            self.assertAlmostEqual(calculated, expected, 15, "at index {0:d}\n"
+                                                             "Max expected at:   {1:f}\n"
+                                                             "Max calculated at: {2:f}".format(i, expected, calculated))
+
+    def testMovingArgMin(self):
+        window = 120
+
+        mv = MovingArgMin(window, 'z')
+        total = np.random.randn(2500)
+        con = deque(maxlen=window)
+        for i, value in enumerate(total):
+            value = float(value)
+            con.append(value)
+            mv.push(dict(z=value))
+            runningMin = min(con)
+
+            expected = len(con) - np.where(np.array(con) == runningMin)[0][0] - 1.
+            calculated = mv.result()
+            self.assertAlmostEqual(calculated, expected, 15, "at index {0:d}\n"
+                                                             "Min expected at:   {1:f}\n"
+                                                             "Min calculated at: {2:f}".format(i, expected, calculated))
+
     def testMovingMaxDeepcopy(self):
         test = MovingMax(3, 'close')
 
